@@ -15,7 +15,7 @@ from xulpymoney.objects.accountoperation import AccountOperation
 from xulpymoney.objects.assets import Assets
 from xulpymoney.objects.bank import Bank
 from xulpymoney.objects.dividend import DividendHomogeneusManager
-from xulpymoney.objects.investmentoperation import InvestmentOperationHomogeneusManager, InvestmentOperation, InvestmentOperationCurrentHeterogeneusManager
+from xulpymoney.objects.investmentoperation import InvestmentOperationHomogeneusManager, InvestmentOperation, InvestmentOperationCurrentHeterogeneusManager, InvestmentOperation_from_row
 from xulpymoney.objects.money import Money
 from xulpymoney.objects.order import OrderManager
 from xulpymoney.objects.percentage import Percentage
@@ -47,6 +47,7 @@ class Investment(QObject):
         self.op_historica=None#setoperinversioneshistorica
         self.selling_expiration=None
         self.merged=False#If this investment is the result of merge several Investments
+        self.daily_adjustment=None
 
         ## Variable with the current product status
         ## 0 No data
@@ -75,12 +76,10 @@ class Investment(QObject):
         #0
         if self.status==0 and statusneeded==1: #MAIN
             start=datetime.now()
-            cur=self.mem.con.cursor()
             self.op=InvestmentOperationHomogeneusManager(self.mem, self)
-            cur.execute("select * from operinversiones where id_inversiones=%s order by datetime", (self.id, ))
-            for row in cur:
-                self.op.append(InvestmentOperation(self.mem).init__db_row(row, self, self.mem.tiposoperaciones.find_by_id(row['id_tiposoperaciones'])))
-            cur.close()
+            rows=self.mem.con.cursor_rows("select * from operinversiones where id_inversiones=%s order by datetime", (self.id, ))
+            for row in rows:
+                self.op.append(InvestmentOperation_from_row(self.mem, row))
             self.status=1
         elif self.status==0 and statusneeded==2:
             self.needStatus(1)
@@ -103,7 +102,7 @@ class Investment(QObject):
             debug("Investment {} took {} to pass from status {} to {}".format(self.name, datetime.now()-start, self.status, statusneeded))
             self.status=3
 
-    def init__create(self, name, venta, cuenta, product, selling_expiration, active, id=None):
+    def init__create(self, name, venta, cuenta, product, selling_expiration, active, daily_adjustment, id=None):
         self.name=name
         self.venta=venta
         self.account=cuenta
@@ -111,6 +110,7 @@ class Investment(QObject):
         self.active=active
         self.selling_expiration=selling_expiration
         self.id=id
+        self.daily_adjustment=daily_adjustment
         return self
 
     ## Replicates an investment with data at datetime
@@ -127,16 +127,16 @@ class Investment(QObject):
         return r
 
     def copy(self ):
-        return Investment(self.mem).init__create(self.name, self.venta, self.account, self.product, self.selling_expiration, self.active, self.id)
+        return Investment(self.mem).init__create(self.name, self.venta, self.account, self.product, self.selling_expiration, self.active, self.daily_adjustment,  self.id)
     
     def save(self):
         """Inserta o actualiza la inversión dependiendo de si id=None o no"""
         cur=self.mem.con.cursor()
         if self.id==None:
-            cur.execute("insert into inversiones (inversion, venta, id_cuentas, active, selling_expiration,products_id) values (%s, %s,%s,%s,%s,%s) returning id_inversiones", (self.name, self.venta, self.account.id, self.active, self.selling_expiration,  self.product.id))    
+            cur.execute("insert into inversiones (inversion, venta, id_cuentas, active, selling_expiration,products_id,daily_adjustment) values (%s, %s,%s,%s,%s,%s,%s) returning id_inversiones", (self.name, self.venta, self.account.id, self.active, self.selling_expiration,  self.product.id, self.daily_adjustment))    
             self.id=cur.fetchone()[0]      
         else:
-            cur.execute("update inversiones set inversion=%s, venta=%s, id_cuentas=%s, active=%s, selling_expiration=%s, products_id=%s where id_inversiones=%s", (self.name, self.venta, self.account.id, self.active, self.selling_expiration,  self.product.id, self.id))
+            cur.execute("update inversiones set inversion=%s, venta=%s, id_cuentas=%s, active=%s, selling_expiration=%s, products_id=%s,daily_adjustment=%s where id_inversiones=%s", (self.name, self.venta, self.account.id, self.active, self.selling_expiration,  self.product.id, self.daily_adjustment, self.id))
         cur.close()
 
     def selling_price(self, type=eMoneyCurrency.Product):
@@ -162,6 +162,7 @@ class Investment(QObject):
         self.product=mqinvestment
         self.active=row['active']
         self.selling_expiration=row['selling_expiration']
+        self.daily_adjustment=row['daily_adjustment']
         return self
 
     ## Función que devuelve un booleano si una cuenta es borrable, es decir, que no tenga registros dependientes.
@@ -293,6 +294,11 @@ class Investment(QObject):
                 debug ("Investment balance: {0} ({1}) en {2} no tiene valor".format(self.name, self.product.id, fecha))
                 return Money(self.mem, 0, self.resultsCurrency(type) )
             return self.Investment_At_Datetime(dtaware_day_end_from_date(fecha, self.mem.localzone_name)).op_actual.balance(quote, type)
+            
+    ## Cuando tengo inversiones apalancadas, se aumenta ficticiamente el saldo y la cantidad invertida, para calculos de totales de patrimonio_riesgo_cero
+    ## Necesito usar solo la cantidad sin apalancar.
+    def balance_real(self, fecha, type=eMoneyCurrency.Product):
+        return self.balance(fecha, type)/self.product.real_leveraged_multiplier()
         
     ## Función que calcula el balance invertido partiendo de las acciones y el precio de compra
     ## Necesita haber cargado mq getbasic y operinversionesactual
@@ -300,12 +306,14 @@ class Investment(QObject):
         if date==None or date==date.today():#Current
             return self.op_actual.invertido(type)
         else:
-            # Creo una vinversion fake para reutilizar codigo, cargando operinversiones hasta date
-            invfake=self.copy()
-            invfake.op=self.op.ObjectManager_copy_until_datetime(dtaware_day_end_from_date(date, self.mem.localzone_name))
-            (invfake.op_actual,  invfake.op_historica)=invfake.op.get_current_and_historical_operations()
+            invfake=self.Investment_At_Datetime(dtaware_day_end_from_date(date, self.mem.localzone_name))
             return invfake.op_actual.invertido(type)
-                
+                            
+    ## Cuando tengo inversiones apalancadas, se aumenta ficticiamente el saldo y la cantidad invertida, para calculos de totales de patrimonio_riesgo_cero
+    ## Necesito usar solo la cantidad sin apalancar.
+    def invested_real(self, date, type=eMoneyCurrency.Product):
+        return self.invertido(date, type)/self.product.real_leveraged_multiplier()
+
     def percentage_to_selling_point(self):       
         """Función que calcula el tpc venta partiendo de las el last y el valor_venta
         Necesita haber cargado mq getbasic y operinversionesactual"""
@@ -315,13 +323,13 @@ class Investment(QObject):
             return Percentage(self.venta-self.product.result.basic.last.quote, self.product.result.basic.last.quote)
         else:#Long short products
             return Percentage(-(self.venta-self.product.result.basic.last.quote), self.product.result.basic.last.quote)
-        
 
 class InvestmentManager(QObject, ObjectManager_With_IdName_Selectable):
     def __init__(self, mem):
         QObject.__init__(self)
         ObjectManager_With_IdName_Selectable.__init__(self)
         self.mem=mem
+        self.setConstructorParameters(self.mem)
 
     def load_from_db(self, sql,  progress=False):
         cur=self.mem.con.cursor()
@@ -381,6 +389,60 @@ class InvestmentManager(QObject, ObjectManager_With_IdName_Selectable):
                     wdg.table.item(i, 7).setBackground(eQColor.Red)
                 if (tpc_venta.value_100()<=Decimal(5) and tpc_venta.isGTZero()) or tpc_venta.isLTZero():
                     wdg.table.item(i, 8).setBackground(eQColor.Green)
+                
+
+    def myqtablewidget_information(self, wdg):
+#        type=eMoneyCurrency.User
+        data=[]
+        for i, inv in enumerate(self.arr):
+            data.append([
+                inv.fullName(), 
+                inv.invertido(), 
+                inv.balance(), 
+                0, 
+                inv#Data with objects
+            ])
+        wdg.setDataWithObjects(
+            [self.tr("Investment"), self.tr("Invested"), self.tr("Balance"), self.tr("Gains")
+            ], 
+            None, 
+            data,  
+            decimals=[0, 0, 6, 2, 2, 2, 2, 2, 2], 
+            zonename=self.mem.localzone_name, 
+            additional=self.myqtablewidget_information_additional
+        )   
+        
+    def myqtablewidget_information_additional(self, wdg):
+        wdg.table.setRowCount(len(wdg.objects())+1)
+#        type=eMoneyCurrency.User
+        wdg.addRow(
+            len(wdg.objects()), 
+            [
+                self.tr("Total"), 
+                self.invested(), 
+                self.balance(), 
+                self.pendiente(), 
+                None
+            ], 
+            zonename=self.mem.localzone_name)
+            
+#            tpc_invertido=inv.op_actual.tpc_total(inv.product.result.basic.last, type)
+#            tpc_venta=inv.percentage_to_selling_point()
+#            if inv.op_actual.shares()>=0: #Long operation
+#                wdg.table.item(i, 0).setIcon(QIcon(":/xulpymoney/up.png"))
+#            else:
+#                wdg.table.item(i, 0).setIcon(QIcon(":/xulpymoney/down.png"))         
+#            if self.mem.gainsyear==True and inv.op_actual.less_than_a_year()==True:
+#                wdg.table.item(i, 7).setIcon(QIcon(":/xulpymoney/new.png"))
+#            if inv.selling_expiration!=None:
+#                if inv.selling_expiration<date.today():
+#                    wdg.table.item(i, 8).setIcon(QIcon(":/xulpymoney/alarm_clock.png"))
+#
+#            if tpc_invertido.isValid() and tpc_venta.isValid():
+#                if tpc_invertido.value_100()<=-Decimal(50):   
+#                    wdg.table.item(i, 7).setBackground(eQColor.Red)
+#                if (tpc_venta.value_100()<=Decimal(5) and tpc_venta.isGTZero()) or tpc_venta.isLTZero():
+#                    wdg.table.item(i, 8).setBackground(eQColor.Green)
 
     def mqtw_active(self, wdg):                
         wdg.setDataFromManager(
@@ -403,32 +465,54 @@ class InvestmentManager(QObject, ObjectManager_With_IdName_Selectable):
     def myqtablewidget_lastCurrent(self, wdg,  percentage):
         type=eMoneyCurrency.User
         data=[]
+        wdg.auxiliar=percentage
         for i, inv in enumerate(self.arr):
-            data.append([
-                "{0} ({1})".format(inv.name, inv.account.name), 
-                inv.op_actual.last().datetime, 
-                inv.op_actual.last().shares, 
-                inv.op_actual.shares(), 
-                inv.balance(None,  type), 
-                inv.op_actual.pendiente(inv.product.result.basic.last, type), 
-                inv.op_actual.last().tpc_total(inv.product.result.basic.last, type=3), 
-                inv.op_actual.tpc_total(inv.product.result.basic.last, type=3),
-                inv.percentage_to_selling_point(), 
-            ])
-        wdg.setData(
+            print(inv.op_actual.last())
+            if inv.op_actual.last() is None:
+                data.append([
+                    "{0} ({1})".format(inv.name, inv.account.name), 
+                    None, 
+                    None, 
+                    inv.op_actual.shares(), 
+                    inv.balance(None,  type), 
+                    inv.op_actual.pendiente(inv.product.result.basic.last, type), 
+                    None,
+                    None,
+                    inv.percentage_to_selling_point(), 
+                    inv, 
+                ])
+            else:
+                data.append([
+                    "{0} ({1})".format(inv.name, inv.account.name), 
+                    inv.op_actual.last().datetime, 
+                    inv.op_actual.last().shares, 
+                    inv.op_actual.shares(), 
+                    inv.balance(None,  type), 
+                    inv.op_actual.pendiente(inv.product.result.basic.last, type), 
+                    inv.op_actual.last().tpc_total(inv.product.result.basic.last, type=3), 
+                    inv.op_actual.tpc_total(inv.product.result.basic.last, type=3),
+                    inv.percentage_to_selling_point(), 
+                    inv, 
+                ])
+        wdg.setDataWithObjects(
             [self.tr("Investment"), self.tr("Last operation"), self.tr("Last shares"), 
             self.tr("Total shares"), self.tr("Balance"), self.tr("Pending"), 
             self.tr("% Last"),  self.tr("% Invested"), self.tr("% Selling point")
             ], 
             None, 
             data,  
-            decimals=[0, 0, 6, 6, 2, 2, 2, 2, 2], 
+            decimals=[0, 0, 6, 6, 2, 2, 2, 2, 2, 2], 
             zonename=self.mem.localzone_name, 
+            additional=self.myqtablewidget_lastCurrent_additional
         )   
-        for i, inv in enumerate(self.arr):
-            lasttpc=inv.op_actual.last().tpc_total(inv.product.result.basic.last, type=3)
-            if lasttpc<percentage:
-                wdg.table.item(i, 6).setBackground(eQColor.Red)
+        
+    def myqtablewidget_lastCurrent_additional(self, wdg):
+        percentage=wdg.auxiliar
+        for i, inv in enumerate(wdg.objects()):
+            if inv.op_actual.last() is not None:
+                lasttpc=inv.op_actual.last().tpc_total(inv.product.result.basic.last, type=3)
+                if lasttpc<percentage:
+                    wdg.table.item(i, 6).setBackground(eQColor.Red)
 
     def mqtw_sellingpoints(self, wdg):                
         data=[]
@@ -687,7 +771,7 @@ class InvestmentManager(QObject, ObjectManager_With_IdName_Selectable):
         name=self.tr( "Virtual investment merging all operations of {}".format(product.name))
         bank=Bank(self.mem).init__create("Merging bank", True, -1)
         account=Account(self.mem, "Merging account",  bank, True, "", self.mem.localcurrency, -1)
-        r=Investment(self.mem).init__create(name, None, account, product, None, True, -1)
+        r=Investment(self.mem).init__create(name, None, account, product, None, True, False, -1)
         r.op=InvestmentOperationHomogeneusManager(self.mem, r)
         r.dividends=DividendHomogeneusManager(self.mem, r)
         for inv in self.arr: #Recorre las inversion del array
@@ -720,14 +804,14 @@ class InvestmentManager(QObject, ObjectManager_With_IdName_Selectable):
         name=self.tr( "Virtual investment merging current operations of {}".format(product.name))
         bank=Bank(self.mem).init__create("Merging bank", True, -1)
         account=Account(self.mem, "Merging account",  bank, True, "", self.mem.localcurrency, -1)
-        r=Investment(self.mem).init__create(name, None, account, product, None, True, -1)    
+        r=Investment(self.mem).init__create(name, None, account, product, None, True, False,  -1)    
         r.op=InvestmentOperationHomogeneusManager(self.mem, r)
         r.dividends=DividendHomogeneusManager(self.mem, r)
         for inv in self.arr: #Recorre las inversion del array
             if inv.product.id==product.id:
                 inv.needStatus(3)
                 for o in inv.op_actual.arr:
-                    r.op.append(InvestmentOperation(self.mem).init__create(o.tipooperacion, o.datetime, r, o.shares, o.impuestos, o.comision,  o.valor_accion,  o.comision,  o.show_in_ranges,  o.currency_conversion,  o.id))
+                    r.op.append(InvestmentOperation(self.mem, o.tipooperacion, o.datetime, r, o.shares, o.impuestos, o.comision,  o.valor_accion,  o.comision,  o.show_in_ranges,  o.currency_conversion,  o.id))
                 for d in inv.DividendManager_of_current_operations().arr:
                     r.dividends.append(d)
         r.dividends.order_by_datetime()
@@ -821,7 +905,6 @@ class InvestmentManager(QObject, ObjectManager_With_IdName_Selectable):
                 if i.product.obsolete==True:
                     continue
 
-
             if tipo==0:
                 arr.append((i.name, i.id))            
             elif tipo==1:
@@ -978,4 +1061,10 @@ class InvestmentManager(QObject, ObjectManager_With_IdName_Selectable):
         except:
             error("InvestmentManager can't order by balance")
             return False
-        
+
+def InvestmentManager_from_list_of_ids( mem, l):
+    invs=InvestmentManager(mem)
+    for inv in mem.data.investments:
+        if inv.id in l:
+            invs.append(inv)
+    return invs
