@@ -12,10 +12,9 @@ from xulpymoney.libxulpymoneytypes import eTickerPosition, eProductType, eQColor
 from xulpymoney.objects.dps import DPSManager
 from xulpymoney.objects.money import Money
 from xulpymoney.objects.quote import Quote, QuoteManager, QuotesResult
-from xulpymoney.objects.ohcl import OHCLDailyManager, OHCLDaily
+from xulpymoney.objects.ohcl import OHCLDaily
 from xulpymoney.objects.split import SplitManager
 from xulpymoney.objects.estimation import EstimationDPSManager, EstimationEPSManager
-from xulpymoney.ui.myqtablewidget import qdate, qcenter
 
 class Product(QObject):
     def __init__(self, mem):
@@ -311,6 +310,13 @@ class Product(QObject):
     ## REturn a money object with the amount and account currency
     def money(self, amount):
         return Money(self.mem, amount, self.currency)
+        
+    ## IBEXA es x2 pero esta en el pricio
+    ## CFD DAX no está en el precio
+    def real_leveraged_multiplier(self):
+        if self.type.id in (eProductType.CFD, eProductType.Future):
+            return self.leveraged.multiplier
+        return 1
 
     def mqtw_tickers(self, mqtw):
         data=[]
@@ -584,152 +590,6 @@ class ProductManager(ObjectManager_With_IdName_Selectable, QObject):
                 wdg.setRowStrikeOut(i)
 
 
-
-## Class that compares two products, removes ohclDaily that aren't in both products
-class ProductComparation(QObject):
-    def __init__(self, mem, product1, product2):
-        QObject.__init__(self)
-        self.mem=mem
-        
-        self.__fromDate=None#None all array.
-        self.product1=product1
-        self.product2=product2     
-        self.set1=OHCLDailyManager(self.mem, self.product1)#Set with common data. Needed in order to not broke self.product1 data
-        self.set2=OHCLDailyManager(self.mem, self.product2)
-        self.product1.needStatus(2)
-        self.product2.needStatus(2)
-        self.__commonDates=None 
-        self.__removeNotCommon()
-        
-    def setFromDate(self, date):
-        """Only affect to functions returning data, not to constructor"""
-        self.__fromDate=date            
-            
-    def canBeMade(self):
-        """Returns a boolean if comparation can be made"""        
-        if len(self.__commonDates)==0:
-            return False
-        return True
-            
-    def __removeNotCommon(self):
-        self.__commonDates=list(set(self.product1.result.ohclDaily.dates()) & set(self.product2.result.ohclDaily.dates()))
-        self.__commonDates=sorted(self.__commonDates, key=lambda c: c,  reverse=False)     
-        for ohcl in self.product1.result.ohclDaily.arr:
-            if ohcl.date in self.__commonDates:
-                self.set1.append(ohcl)
-        for ohcl in self.product2.result.ohclDaily.arr:
-            if ohcl.date in self.__commonDates:
-                self.set2.append(ohcl)
-
-    def myqtablewidget(self, wdg):
-        arr=[]#date, product1, product2
-        for i, dat in enumerate(self.__commonDates):
-            arr.append((dat, self.set1.arr[i].close, self.set2.arr[i].close))
-            
-        wdg.table.setColumnCount(3)
-        wdg.table.setHorizontalHeaderItem(0, qcenter(self.tr("Date" )))
-        wdg.table.setHorizontalHeaderItem(1, qcenter(self.product1.name))
-        wdg.table.setHorizontalHeaderItem(2,  qcenter(self.product2.name))
-        ##DATA 
-        wdg.table.clearContents()
-        wdg.applySettings()  
-        wdg.table.setRowCount(len(self.__commonDates))
-        
-        for i, a in enumerate(arr):
-            wdg.table.setItem(i, 0, qdate(a[0]))
-            wdg.table.setItem(i, 1, self.product1.money(a[1]).qtablewidgetitem())
-            wdg.table.setItem(i, 2, self.product1.money(a[2]).qtablewidgetitem())
-        
-    def index(self, date):
-        """Returns date index in array"""
-        if date==None:
-            return 0
-        for i, d in enumerate(self.__commonDates):
-            if date<=d:
-                return i
-        return 0
-
-    def dates(self):
-        """Returns a list with common dates"""
-        return self.__commonDates[self.index(self.__fromDate):len(self.__commonDates)]
-        
-    def product1Closes(self):
-        r=[]
-        for ohcl in self.set1.arr:
-            r.append(ohcl.close)
-        return r[self.index(self.__fromDate):len(self.__commonDates)]
-
-    def product2Closes(self):
-        r=[]
-        for ohcl in self.set2.arr:
-            r.append(ohcl.close)
-        return r[self.index(self.__fromDate):len(self.__commonDates)]
-    
-    def product1ClosesDividingFirst(self):
-        """Divides set1 by a factor to get the same price in the first ohcl"""
-        idx=self.index(self.__fromDate)
-        factor=self.set1.arr[idx].close/self.set2.arr[idx].close
-        r=[]
-        for ohcl in self.set1.arr:
-            r.append(ohcl.close/factor)
-        return r[idx:len(self.__commonDates)]
-
-    def product1ClosesDividingFirstLeveragedReduced(self):
-        """Divides set1 by a factor to get the same price in the first ohcl
-        It controls leverage too"""
-        idx=self.index(self.__fromDate)
-        factor=self.set1.arr[idx].close/self.set2.arr[idx].close*self.product1.leveraged.multiplier
-        r=[]
-        for ohcl in self.set1.arr:
-            r.append(ohcl.close/factor)
-        return r[idx:len(self.__commonDates)]
-        
-    def product1PercentageFromFirstProduct2Price(self):
-        """Usa el primer valor de set 2 y la va sumando los porcentajes de set1. """
-        idx=self.index(self.__fromDate)
-        r=[]
-        last=self.set2.arr[idx].close
-        r.append(last)
-        for index in range(idx+1, self.set1.length()):
-            last=last*(1+ self.set1.arr[index-1].percentage(self.set1.arr[index]).value)
-            r.append(last)
-        return r 
-        
-    def product1PercentageFromFirstProduct2PriceLeveragedReduced(self):
-        """Usa el primer valor de set 2 y la va sumando los porcentajes de set1. Contrala leverages"""
-        idx=self.index(self.__fromDate)
-        r=[]
-        last=self.set2.arr[idx].close
-        r.append(last)
-        for index in range(idx+1, self.set1.length()):
-            last=last*(1+ self.set1.arr[index-1].percentage(self.set1.arr[index]).value/self.product1.leveraged.multiplier)
-            r.append(last)
-        return r
-        
-    def product1PercentageFromFirstProduct2InversePrice(self):
-        """Usa el primer valor de set 2 y la va sumando los porcentajes de set1. """
-        idx=self.index(self.__fromDate)
-        r=[]
-        last=self.set2.arr[idx].close
-        r.append(last)
-        for index in range(idx+1, self.set1.length()):
-            last=last*(1- self.set1.arr[index-1].percentage(self.set1.arr[index]).value)
-            r.append(last)
-        return r 
-        
-    def product1PercentageFromFirstProduct2InversePriceLeveragedReduced(self):
-        """Usa el primer valor de set 2 y la va sumando los porcentajes de set1. Contrala leverages"""
-        idx=self.index(self.__fromDate)
-        r=[]
-        last=self.set2.arr[idx].close
-        r.append(last)
-        for index in range(idx+1, self.set1.length()):
-            last=last*(1- self.set1.arr[index-1].percentage(self.set1.arr[index]).value/self.product1.leveraged.multiplier)
-            r.append(last)
-        return r
-        
-
-                
 ## Class to manage source xulpymoney_run_client and other scripts
 ## Update works creating a file in ____ and theen executing xulpymoney_run_client
 class ProductUpdate:
@@ -770,7 +630,6 @@ class ProductUpdate:
         r=set()
         used=""
         ##### BOLSAMADRID #####
-        cur=mem.con.cursor()
         sqls=[
             "select * from products where type in (1,4) and obsolete=false and stockmarkets_id=1 and isin is not null and isin<>'' {} order by name".format(used), 
             "select * from products where type in ({}) and obsolete=false and stockmarkets_id=1 and isin is not null {} order by name".format(eProductType.PublicBond, used), 
@@ -781,16 +640,10 @@ class ProductUpdate:
             "select * from products where tickers[{}] is not null and obsolete=false {} order by name".format(eTickerPosition.postgresql(eTickerPosition.Morningstar),  used)
         ]
         for sql in sqls:
-            cur.execute(sql)
-            for row in cur:
+            for row in mem.con.cursor_rows(sql):
                 r.add(row['id'])
-        cur.close()
         return r
 
-
-
-
-
     ## Function that executes xulpymoney_run_client and generate a QuoteManager 
     ## Source commands must be created before in file "{}/clients.txt".format(dir_tmp)
     ## Output of the xulpymoney_run_client command is generated in ("{}/clients_result.txt".format(self.mem.dir_tmp),
