@@ -1,8 +1,7 @@
-from PyQt5.QtCore import Qt, pyqtSlot
+from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QDialog, QMenu,  QMessageBox, QAbstractItemView
 from datetime import date,  timedelta, datetime
 from logging import debug
-from xulpymoney.casts import b2c,  c2b
 from xulpymoney.objects.account import Account
 from xulpymoney.libxulpymoneytypes import eComment, eConcept
 from xulpymoney.objects.accountoperation import AccountOperation, AccountOperationManagerHomogeneus
@@ -10,7 +9,7 @@ from xulpymoney.objects.assets import Assets
 from xulpymoney.objects.comment import Comment
 from xulpymoney.objects.creditcardoperation import CreditCardOperationManager
 from xulpymoney.objects.currency import currencies_qcombobox
-from xulpymoney.objects.investmentoperation import InvestmentOperation
+from xulpymoney.objects.investmentoperation import InvestmentOperation_from_accountoperation
 from xulpymoney.ui.Ui_frmAccountsReport import Ui_frmAccountsReport
 from xulpymoney.ui.frmAccountOperationsAdd import frmAccountOperationsAdd
 from xulpymoney.ui.frmCreditCardsAdd import frmCreditCardsAdd
@@ -38,8 +37,6 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
         self.wdgDtPago.show_timezone(False)
         self.wdgDtPago.setTitle(self.tr("Select payment time"))
         
-        
-        self.accountoperations=None#AccountOperationManager. Selected will be an AccountOperation
         self.creditcardoperations=CreditCardOperationManager(self.mem)#CreditCardOperationManager. Selected will be another CreditCardOperationManager
           
         self.mqtwOperations.setSettings(self.mem.settings, "frmAccountsReport", "mqtwOperations")
@@ -59,16 +56,19 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
         currencies_qcombobox(self.cmbCurrency)
         self.mem.data.banks_active().qcombobox(self.cmbEB)
                     
-        if self.account==None:
+        if self.account is None:
+            self.account_insert=True
+            self.account=Account(self.mem)
             self.lblTitulo.setText(self.tr("New account data"))
             self.tab.setCurrentIndex(0)
             self.tab.setTabEnabled(1, False)
             self.tab.setTabEnabled(2, False)
-            self.chkActiva.setChecked(Qt.Checked)
+            self.chkActiva.setChecked(True)
             self.chkActiva.setEnabled(False)
             self.mqtwOperations.setEnabled(False)
             self.cmdDatos.setText(self.tr("Add a new account"))
         else:
+            self.account_insert=False
             self.account.needStatus(1)
             self.tab.setCurrentIndex(0)
             self.lblTitulo.setText(self.account.name)
@@ -78,13 +78,12 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
             self.cmbEB.setEnabled(False)    
             self.cmbCurrency.setCurrentIndex(self.cmbCurrency.findData(self.account.currency))
             self.cmbCurrency.setEnabled(False)
-            self.chkActiva.setChecked(b2c(self.account.active))
+            self.chkActiva.setChecked(self.account.active)
             self.cmdDatos.setText(self.tr("Update account data"))
 
             dtFirst=Assets(self.mem).first_datetime_allowed_estimated()       
             dtLast=Assets(self.mem).last_datetime_allowed_estimated()
             self.wdgYM.initiate(dtFirst.year,  dtLast.year, date.today().year, date.today().month)
-            self.wdgYM.changed.connect(self.on_wdgYM_changed)
             self.on_wdgYM_changed()
             self.mqtwCreditCards_update()
 
@@ -127,31 +126,26 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
         self.mqtwCreditCards_update()
 
     def on_cmdDatos_released(self):
-        id_entidadesbancarias=int(self.cmbEB.itemData(self.cmbEB.currentIndex()))
-        cuenta=self.txtAccount.text()
-        numerocuenta=self.txtNumero.text()
-        active=c2b(self.chkActiva.checkState())
-        currency=self.cmbCurrency.itemData(self.cmbCurrency.currentIndex())
+        id_entidadesbancarias=self.cmbEB.itemData(self.cmbEB.currentIndex())
+        if id_entidadesbancarias is None:
+            qmessagebox(self.tr("You must select a bank"))
+            return
 
-        if self.account==None:
-            cu=Account(self.mem, cuenta, self.mem.data.banks_active().find_by_id(id_entidadesbancarias), active, numerocuenta, self.mem.currencies.find_by_id(currency), None)
-            cu.save()
-            self.mem.data.accounts.append(cu) #Always to active
-        else:
-            self.account.bank=self.mem.data.banks_active().find_by_id(id_entidadesbancarias)
-            self.account.name=cuenta
-            self.account.number=numerocuenta
-            self.account.active=active
-            self.account.currency=currency
-            self.account.save()
-            self.lblTitulo.setText(self.account.name)
+        self.account.bank=self.mem.data.banks_active().find_by_id(id_entidadesbancarias)
+        self.account.name=self.txtAccount.text()
+        self.account.number=self.txtNumero.text()
+        self.account.active=self.chkActiva.isChecked()
+        self.account.currency=self.cmbCurrency.itemData(self.cmbCurrency.currentIndex())
+        self.account.save()
         self.mem.con.commit()
         
-        if self.account==None:
+        self.lblTitulo.setText(self.account.name)
+        self.cmdDatos.setEnabled(False)
+        
+        if self.account_insert is True:
+            self.mem.data.accounts.append(self.account)
             self.done(0)
-        self.cmdDatos.setEnabled(False)   
 
-    @pyqtSlot()
     def on_wdgYM_changed(self):
         lastMonthBalance=self.account.balance(date(self.wdgYM.year, self.wdgYM.month, 1)-timedelta(days=1), type=2)     
         self.accountoperations=AccountOperationManagerHomogeneus(self.mem, self.account)     
@@ -227,19 +221,18 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
             
     @pyqtSlot() 
     def on_actionInvestmentOperationDelete_triggered(self):
-        investmentoperation=InvestmentOperation(self.mem).init__from_accountoperation(self.mqtwOperations.selected)
+        investmentoperation=InvestmentOperation_from_accountoperation(self.mem, self.mqtwOperations.selected)
         investmentoperation.investment.op.remove(investmentoperation)
         self.mem.con.commit()     
-        debug("Borrando investment operation "+  investmentoperation)
+        debug("Borrando investment operation "+  str(investmentoperation))
         self.on_wdgYM_changed()
 
-
     @pyqtSlot() 
     def on_actionInvestmentOperationEdit_triggered(self):
-        investmentoperation=InvestmentOperation(self.mem).init__from_accountoperation(self.mqtwOperations.selected)
+        investmentoperation=InvestmentOperation_from_accountoperation(self.mem, self.mqtwOperations.selected)
         w=frmInvestmentOperationsAdd(self.mem, investmentoperation.investment, investmentoperation, self)
         w.exec_()
-        debug("Edit investmentoperation {}".format(self.mqtwOperations.selected))
+        debug("Edit investmentoperation {}".format(investmentoperation))
         self.on_wdgYM_changed()
 
     @pyqtSlot()
@@ -255,7 +248,6 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
         d.setWidgets(wdgConceptsHistorical(self.mem, concepto, d))
         d.exec_()
 
-
     ## Selection can be only one row, due to table definitions
     def on_mqtwOperations_customContextMenuRequested(self,  pos):      
         if self.account.qmessagebox_inactive() or self.account.bank.qmessagebox_inactive():
@@ -303,9 +295,9 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
                 menu.addAction(self.actionInvestmentOperationDelete)
         menu.exec_(self.mqtwOperations.table.mapToGlobal(pos))
 
-
     def on_mqtwCreditCards_tableSelectionChanged(self):
             self.mqtwCreditCardsOperations_update()
+
     def on_mqtwCreditCards_customContextMenuRequested(self,  pos):
         if self.account.qmessagebox_inactive():
             return 
@@ -348,27 +340,30 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
         if self.account.qmessagebox_inactive() or self.account.bank.qmessagebox_inactive() or self.mqtwCreditCards.selected.qmessagebox_inactive():
             return
 
-        if len(self.mqtwCreditCardOperations.selected)==0: # 0 o más de 1
+        if self.mqtwCreditCardOperations.selected is None:
+            return 
+
+        if len(self.mqtwCreditCardOperations.selected)==0:
             self.grpPago.setEnabled(False)
             self.actionCreditCardOperDelete.setEnabled(False)
             self.actionCreditCardOperEdit.setEnabled(False)
             self.actionCreditCardOperRefund.setEnabled(False)
             self.actionConceptReport.setEnabled(False)
-        elif len(self.mqtwCreditCardOperations.selected)==1: # 0 o más de 1
-            self.grpPago.setEnabled(True)
-            self.actionCreditCardOperDelete.setEnabled(False)
-            self.actionCreditCardOperEdit.setEnabled(False)
-            self.actionCreditCardOperRefund.setEnabled(False)
-            self.actionConceptReport.setEnabled(False)
-        else:
+        elif len(self.mqtwCreditCardOperations.selected)==1:
             self.grpPago.setEnabled(True)
             self.actionCreditCardOperDelete.setEnabled(True)
             self.actionCreditCardOperEdit.setEnabled(True)
+            self.actionConceptReport.setEnabled(True)
             if self.mqtwCreditCards.selected.pagodiferido==True and self.mqtwCreditCardOperations.selected[0].importe<0:#Only difered purchases
                 self.actionCreditCardOperRefund.setEnabled(True)
             else:
                 self.actionCreditCardOperRefund.setEnabled(False)
-            self.actionConceptReport.setEnabled(True)
+        else:# >=2
+            self.grpPago.setEnabled(True)
+            self.actionCreditCardOperDelete.setEnabled(False)
+            self.actionCreditCardOperEdit.setEnabled(False)
+            self.actionConceptReport.setEnabled(False)
+            self.actionCreditCardOperRefund.setEnabled(False)
             
         menu=QMenu()
         menu.addAction(self.actionCreditCardOperAdd)
@@ -381,11 +376,12 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
         menu.exec_(self.mqtwCreditCardOperations.table.mapToGlobal(pos))
     
     def on_mqtwCreditCardOperations_tableSelectionChanged(self):
-        r=CreditCardOperationManager(self.mem)
+        #Manager of selection to be reused
+        self.mqtwCreditCardOperations_selectedmanager=CreditCardOperationManager(self.mem)
         for o in self.mqtwCreditCardOperations.selected:
-            r.append(o)
+            self.mqtwCreditCardOperations_selectedmanager.append(o)
         #Calcula el balance
-        self.lblPago.setText(self.mem.localmoney(r.balance()).string())
+        self.lblPago.setText(self.mem.localmoney(self.mqtwCreditCardOperations_selectedmanager.balance()).string())
 
     def mqtwCreditCardsOperations_update(self):
         self.tabOpertarjetasDiferidas.setCurrentIndex(0)
@@ -396,18 +392,19 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
                 self.grpPago.setEnabled(True)
                 self.creditcardoperations.load_from_db(self.mem.con.mogrify("select * from opertarjetas where id_tarjetas=%s and pagado=false", [self.mqtwCreditCards.selected.id, ]))
                 self.creditcardoperations.myqtablewidget(self.mqtwCreditCardOperations)
+                self.mqtwCreditCardOperations.setOrderBy(0, False)
             else:
                 self.grpPago.setEnabled(False)
 
     def on_cmdPago_released(self):
-        c=AccountOperation(self.mem, self.wdgDtPago.datetime(), self.mem.conceptos.find_by_id(40), self.mem.tiposoperaciones.find_by_id(7), self.mqtwCreditCardOperations.selected.balance(), "Transaction in progress", self.account, None)
+        c=AccountOperation(self.mem, self.wdgDtPago.datetime(), self.mem.conceptos.find_by_id(40), self.mem.tiposoperaciones.find_by_id(7), self.mqtwCreditCardOperations_selectedmanager.balance(), "Transaction in progress", self.account, None)
         c.save()
         
         c.comentario=Comment(self.mem).encode(eComment.CreditCardBilling, self.mqtwCreditCards.selected, c)
         c.save()
         
         #Modifica el registro y lo pone como pagado y la datetime de pago y añade la opercuenta
-        for o in self.mqtwCreditCardOperations.selected.arr:
+        for o in self.mqtwCreditCardOperations_selectedmanager.arr:
             o.fechapago=self.wdgDtPago.datetime()
             o.pagado=True
             o.opercuenta=c
@@ -451,9 +448,12 @@ class frmAccountsReport(QDialog, Ui_frmAccountsReport):
 
     def on_txtAccount_textChanged(self):
         self.cmdDatos.setEnabled(True)
+
     def on_txtNumero_textChanged(self):
         self.cmdDatos.setEnabled(True)
+
     def on_cmbEB_currentIndexChanged(self, index):
         self.cmdDatos.setEnabled(True)
+
     def on_chkActiva_stateChanged(self,  state):
         self.cmdDatos.setEnabled(True)
