@@ -4,13 +4,13 @@ from PyQt5.QtWidgets import QApplication, QDialog,  QMenu
 from datetime import date, timedelta
 from xulpymoney.casts import c2b
 from xulpymoney.datetime_functions import days2string
+from xulpymoney.objects.currency import currency_symbol
 from xulpymoney.objects.money import Money
 from xulpymoney.objects.investment import Investment
 from xulpymoney.objects.percentage import Percentage
 from xulpymoney.objects.investmentoperation import InvestmentOperationHomogeneusManager
 from xulpymoney.libxulpymoneytypes import eMoneyCurrency
 from xulpymoney.ui.Ui_frmInvestmentReport import Ui_frmInvestmentReport
-from xulpymoney.ui.myqcharts import VCTemporalSeries
 from xulpymoney.ui.frmInvestmentOperationsAdd import frmInvestmentOperationsAdd
 from xulpymoney.ui.frmDividendsAdd import frmDividendsAdd
 from xulpymoney.ui.frmSellingPoint import frmSellingPoint
@@ -48,8 +48,10 @@ class frmInvestmentReport(QDialog, Ui_frmInvestmentReport):
         self.mqtwInvestmentHistoricalAccountCurrency.setSettings(self.mem.settings,  "frmInvestmentReport", "mqtwInvestmentHistoricalAccountCurrency")
         self.ise.cmd.released.connect(self.on_cmdISE_released)
         self.mem.data.accounts_active().qcombobox(self.cmbAccount)
-        self.viewChart=None
-        
+
+        self.wdgTS.setSettings(self.mem.settings, "frmInvestmentReport", "wdgTS")
+        self.wdgTS.ts.setTitle(self.tr("Investment chart"))
+            
         if self.investment==None:#ADD
             self.cmdInvestment.setText(self.tr("Add a new investment"))
             self.lblTitulo.setText(self.tr("New investment"))
@@ -66,6 +68,7 @@ class frmInvestmentReport(QDialog, Ui_frmInvestmentReport):
             self.lblTitulo.setText(self.investment.name)
             self.txtInvestment.setText(self.investment.name)
             self.txtVenta.setText(self.investment.venta)
+            self.chkDailyAdjustment.setChecked(self.investment.daily_adjustment)
             if self.investment.selling_expiration==None:
                 self.chkExpiration.setCheckState(Qt.Unchecked)
             else:
@@ -74,10 +77,6 @@ class frmInvestmentReport(QDialog, Ui_frmInvestmentReport):
             self.ise.setSelected(self.investment.product)
             self.cmdPuntoVenta.setEnabled(True)
             self.cmbAccount.setCurrentIndex(self.cmbAccount.findData(self.investment.account.id))
-
-            #Removes contract tab when it isn't neccessary
-            if self.investment.product.high_low==False:
-                self.tab.removeTab(6)
             
             #CmbAccount está desabilitado si hay dividends o operinversiones
             if self.investment.op.length()!=0:
@@ -273,7 +272,7 @@ class frmInvestmentReport(QDialog, Ui_frmInvestmentReport):
         if self.investment.account.currency==self.investment.product.currency:
             self.grpDividendsAccountCurrency.hide()
         else:
-            self.investment.dividends.myqtablewidget(self.mqtwDividendsAccountCurrency, type=2)
+            self.investment.dividends.myqtablewidget(self.mqtwDividendsAccountCurrency, eMoneyCurrency.Product, not self.chkHistoricalDividends.isChecked())
         if state==Qt.Unchecked:
             estimacion=self.investment.product.estimations_dps.currentYear()
             if estimacion.estimation!=None:
@@ -314,6 +313,10 @@ class frmInvestmentReport(QDialog, Ui_frmInvestmentReport):
         if self.investment==None or self.investment.merged==False:
             self.cmdInvestment.setEnabled(True)
 
+    def on_chkDailyAdjustment_stateChanged(self, state):
+        if self.investment==None or self.investment.merged==False:
+            self.cmdInvestment.setEnabled(True)
+
     def on_cmdToday_released(self):
         self.calExpiration.setSelectedDate(date.today())
 
@@ -323,6 +326,7 @@ class frmInvestmentReport(QDialog, Ui_frmInvestmentReport):
             return
         inversion=self.txtInvestment.text()
         venta=self.txtVenta.decimal()
+        daily_adjustment=self.chkDailyAdjustment.isChecked()
         account=self.mem.data.accounts_active().find_by_id(self.cmbAccount.itemData(self.cmbAccount.currentIndex()))
         if account is None:
             qmessagebox(self.tr("You must select an account"))
@@ -340,7 +344,7 @@ class frmInvestmentReport(QDialog, Ui_frmInvestmentReport):
             self.mem.data.products.append(product)        
 
         if self.investment==None: #insertar
-            self.investment=Investment(self.mem).init__create(inversion,   venta,  account, product, expiration, True)      
+            self.investment=Investment(self.mem).init__create(inversion,   venta,  account, product, expiration, True, daily_adjustment )
             self.investment.save()
             self.mem.con.commit()    
             #Lo añade con las operaciones vacias pero calculadas.
@@ -353,6 +357,7 @@ class frmInvestmentReport(QDialog, Ui_frmInvestmentReport):
             self.investment.venta=venta
             self.investment.product=product
             self.investment.selling_expiration=expiration
+            self.investment.daily_adjustment=daily_adjustment
             self.investment.save()##El id y el id_cuentas no se pueden modificar
             self.mem.con.commit()
             self.cmdInvestment.setEnabled(False)
@@ -483,50 +488,32 @@ class frmInvestmentReport(QDialog, Ui_frmInvestmentReport):
             self.investment.dividends.selected=None
         print ("Dividend selected: " +  str(self.investment.dividends.selected))        
 
-
-        
     def on_tab_currentChanged(self, index): 
         if  index==5: #Repaints chart
-            if self.viewChart!=None:
-                self.layChart.removeWidget(self.viewChart)
-                self.viewChart.close()
-            self.viewChart=VCInvestment()
-            self.viewChart.setInvestment(self.investment)
-            self.viewChart.generate()
-            self.layChart.addWidget(self.viewChart)
+            self.wdgTS_update()
         
-##View chart of an investment
-class VCInvestment(VCTemporalSeries):
-    def __init__(self):
-        VCTemporalSeries.__init__(self)
         
-    def setInvestment(self, investment):
-        self.investment=investment
-        self.mem=self.investment.mem
-        if self.investment.op.length()>0:
-            self.from_=self.investment.op.first().datetime-timedelta(days=30)
-
-    ## Just draw the chart with selected options. To update it just close this object and create another one
-    def generate(self):
+    def wdgTS_update(self):
+        self.wdgTS.clear()
+        self.investment.needStatus(3)
         if self.investment.op.length()>0:
+            self.wdgTS.ts.setXFormat("date", self.tr("Date"))
+            self.wdgTS.ts.setYFormat(self.investment.product.currency, self.tr("Amount ({})").format(currency_symbol(self.investment.account.currency)), self.investment.product.decimals)
             #Gets investment important datetimes: operations, dividends, init and current time. For each datetime adds another at the beginning of the day, to get mountains in graph
             datetimes=set()
             datetimes.add(self.investment.op.first().datetime -timedelta(days=30))
             for op in self.investment.op.arr:
                 datetimes.add(op.datetime)
-                datetimes.add(op.datetime.replace(hour=0, minute=0, second=0))
-            self.investment.needStatus(3)
+                datetimes.add(op.datetime-timedelta(seconds=1))
             for dividend in self.investment.dividends.arr:
                 datetimes.add(dividend.datetime)
-                datetimes.add(dividend.datetime.replace(hour=0, minute=0, second=0))
             datetimes.add(self.mem.localzone.now())
-            datetimes.add(self.mem.localzone.now().replace(hour=0, minute=0, second=0))
             datetimes_list=list(datetimes)
             datetimes_list.sort()
-            
+                    
             #Progress dialog 
-            self.setProgressDialogEnabled(True)
-            self.setProgressDialogAttributes(
+            self.wdgTS.ts.setProgressDialogEnabled(True)
+            self.wdgTS.ts.setProgressDialogAttributes(
                     None, 
                     self.tr("Loading {} special datetimes").format(len(datetimes_list)), 
                     QIcon(":xulpymoney/coins.png"), 
@@ -535,14 +522,14 @@ class VCInvestment(VCTemporalSeries):
             )
             
             #Draw lines
-            invested=self.appendTemporalSeries(self.tr("Invested amount"))
-            balance=self.appendTemporalSeries(self.tr("Investment balance"))
-            gains=self.appendTemporalSeries(self.tr("Net gains"))
-            dividends=self.appendTemporalSeries(self.tr("Net dividends"))
-            gains_dividends=self.appendTemporalSeries(self.tr("Net gains with dividends"))
+            invested=self.wdgTS.ts.appendTemporalSeries(self.tr("Invested amount"))
+            balance=self.wdgTS.ts.appendTemporalSeries(self.tr("Investment balance"))
+            gains=self.wdgTS.ts.appendTemporalSeries(self.tr("Net gains"))
+            dividends=self.wdgTS.ts.appendTemporalSeries(self.tr("Net dividends"))
+            gains_dividends=self.wdgTS.ts.appendTemporalSeries(self.tr("Net gains with dividends"))
             for i, dt in enumerate(datetimes_list):
                 #Shows progress dialog
-                self.setProgressDialogNumber(i+1)
+                self.wdgTS.ts.setProgressDialogNumber(i+1)
                 #Calculate dividends in datetime
                 dividend_net=0
                 for dividend in self.investment.dividends.arr:
@@ -551,14 +538,13 @@ class VCInvestment(VCTemporalSeries):
                 #Append data of that datetime
                 tmp_investment=self.investment.Investment_At_Datetime(dt)
                 gains_net=tmp_investment.op_historica.consolidado_neto().amount
-                self.appendTemporalSeriesData(invested, dt, tmp_investment.invertido().amount)
-                self.appendTemporalSeriesData(gains_dividends, dt, gains_net+dividend_net)
-                self.appendTemporalSeriesData(balance, dt, tmp_investment.balance(dt.date()).amount)
-                self.appendTemporalSeriesData(dividends, dt, dividend_net)
-                self.appendTemporalSeriesData(gains, dt, gains_net)
-            self.setTitle(self.tr("Investment chart"))
-            self.display()
+                self.wdgTS.ts.appendTemporalSeriesData(invested, dt, tmp_investment.invertido().amount)
+                self.wdgTS.ts.appendTemporalSeriesData(gains_dividends, dt, gains_net+dividend_net)
+                self.wdgTS.ts.appendTemporalSeriesData(balance, dt, tmp_investment.balance(dt.date()).amount)
+                self.wdgTS.ts.appendTemporalSeriesData(dividends, dt, dividend_net)
+                self.wdgTS.ts.appendTemporalSeriesData(gains, dt, gains_net)
+            self.wdgTS.display()
             #Markers are generated in display so working with markers must be after it
-            self.chart().legend().markers(gains)[0].clicked.emit()
-            self.chart().legend().markers(dividends)[0].clicked.emit()
-            self.chart().legend().markers(balance)[0].clicked.emit()
+            self.wdgTS.ts.chart().legend().markers(gains)[0].clicked.emit()
+            self.wdgTS.ts.chart().legend().markers(dividends)[0].clicked.emit()
+            self.wdgTS.ts.chart().legend().markers(balance)[0].clicked.emit()
