@@ -10,13 +10,12 @@ import datetime
 import logging
 from xulpymoney.datetime_functions import dtaware_day_start_from_date, dt_day_start
 from xulpymoney.ui.myqlineedit import myQLineEdit
-from xulpymoney.ui.myqcharts import eOHCLDuration
 from xulpymoney.objects.investment import Investment
 from xulpymoney.objects.investmentoperation import InvestmentOperation, InvestmentOperationHomogeneusManager
 from xulpymoney.objects.money import Money
 from xulpymoney.objects.percentage import Percentage
 from xulpymoney.casts import string2list_of_integers
-from xulpymoney.libxulpymoneytypes import eHistoricalChartAdjusts, eOperationType
+from xulpymoney.libxulpymoneytypes import eHistoricalChartAdjusts, eOperationType, eOHCLDuration
 from xulpymoney.ui.wdgOpportunitiesAdd import wdgOpportunitiesAdd
 
 ## Main class that sets a product (can add an investment too) with setProduct function
@@ -35,6 +34,15 @@ class wdgProductHistoricalChart(QWidget, Ui_wdgProductHistoricalChart):
         pen.setColor(color)
         return pen
 
+
+    def setOHCLDuration(self, ohclduration):
+        self.__ohclduration=ohclduration
+        
+        
+    ## @param list_decimals List of Decimlas with the range value where a line must be drawn
+    def setDrawRangeLines(self, list_decimals):
+        self._drawRangeLines=list_decimals
+
     def setProduct(self, product, investment=None):
         self.product=product
         self.investment=investment
@@ -97,7 +105,6 @@ class wdgProductHistoricalChart(QWidget, Ui_wdgProductHistoricalChart):
             for ohcl in self.setohcl.arr:
                 if ohcl.datetime()>=selected_datetime:
                     self.wdgTS.ts.appendCandlestickSeriesData(candle, ohcl.datetime(), ohcl.open, ohcl.high, ohcl.close, ohcl.low)
-            self.wdgTS.ts.setOHCLDuration(self.cmbOHCLDuration.itemData(self.cmbOHCLDuration.currentIndex()))
             
             
         dvm=self.setohcl.DatetimeValueManager("close")
@@ -175,6 +182,15 @@ class wdgProductHistoricalChart(QWidget, Ui_wdgProductHistoricalChart):
                 self.wdgTS.ts.appendTemporalSeriesData(average_price, self.investment.op_actual.first().datetime, m_average_price.amount)
                 self.wdgTS.ts.appendTemporalSeriesData(average_price, self.mem.localzone.now() + datetime.timedelta(days=1), m_average_price.amount)
 
+        if hasattr(self,  "_drawRangeLines") is True: #Draws range linbes
+            for range in self._drawRangeLines:
+                range=round(range, self.product.decimals)
+                m_range=self.product.money(range)
+                tsrange=self.wdgTS.ts.appendTemporalSeries(self.tr("Range at {}".format(m_range)))
+                tsrange.setColor(QColor(95, 154, 12))
+                self.wdgTS.ts.appendTemporalSeriesData(tsrange, selected_datetime, range)
+                self.wdgTS.ts.appendTemporalSeriesData(tsrange, self.mem.localzone.now(), range)
+
     def display(self):
         self.wdgTS.display()
 
@@ -417,7 +433,7 @@ class wdgProductHistoricalBuyChart(wdgProductHistoricalChart):
         percentage=Percentage(self.spnGainsPercentage.value(), 100)
         selected_datetime= dtaware_day_start_from_date(self.dtFrom.date().toPyDate(), self.mem.localzone_name)
 
-        inv=Investment(self.mem).init__create("Buy Chart", None, None, self.product, None, True, -1)
+        inv=Investment(self.mem).init__create("Buy Chart", None, None, self.product, None, True, False -1)
         inv.op=InvestmentOperationHomogeneusManager(self.mem, inv)
         p_last_operation=Percentage(self.txtLastOperationPercentage.decimal(), 100)
 
@@ -425,18 +441,19 @@ class wdgProductHistoricalBuyChart(wdgProductHistoricalChart):
         #index=0 purchase, 1 = first reinvestment
         lastIO=None
         for index, amount in enumerate(self.amounts):
-            lastIO=InvestmentOperation(self.mem).init__create  (   self.mem.tiposoperaciones.find_by_id(4), 
-                                                                                            self.mem.localzone.now(), 
-                                                                                            inv, 
-                                                                                            int(self.amounts[index]/m_purchase.amount), 
-                                                                                            0, 
-                                                                                            0, 
-                                                                                            m_purchase.amount, 
-                                                                                            "",  
-                                                                                            True, 
-                                                                                            1,  
-                                                                                            -10000
-                                                                                        )
+            lastIO=InvestmentOperation(self.mem, 
+                                                            self.mem.tiposoperaciones.find_by_id(4), 
+                                                            self.mem.localzone.now(), 
+                                                            inv, 
+                                                            int(self.amounts[index]/m_purchase.amount), 
+                                                            0, 
+                                                            0, 
+                                                            m_purchase.amount, 
+                                                            "",  
+                                                            True, 
+                                                            1,  
+                                                            -10000
+                                                        )
             inv.op.append(lastIO)
             (inv.op_actual, inv.op_historica)=inv.op.get_current_and_historical_operations()
             new_purchase_price=self.wdgTS.ts.appendTemporalSeries(self.tr("Purchase price {}: {}").format(index, m_purchase.string()))
