@@ -1,211 +1,24 @@
 from PyQt5.QtCore import pyqtSlot,  Qt
 from PyQt5.QtGui import QIcon, QFont
 from PyQt5.QtWidgets import  QWidget, QMenu, QProgressDialog, QVBoxLayout, QHBoxLayout, QAbstractItemView, QTableWidgetItem, QLabel, QApplication
-from datetime import date, datetime, timedelta
+from datetime import date, datetime
 from decimal import Decimal
 from logging import info, debug
-from xulpymoney.datetime_functions import dtaware_day_end_from_date, date_last_of_the_month, date_first_of_the_next_x_months
+from xulpymoney.datetime_functions import dtaware_day_end_from_date
+from xulpymoney.objects.concept import ConceptManager_considered_dividends_in_totals
 from xulpymoney.objects.dividend import DividendHeterogeneusManager
 from xulpymoney.objects.investmentoperation import InvestmentOperationHistoricalHeterogeneusManager
+from xulpymoney.objects.totalmonth import TotalMonthManager_from_manager_extracting_year, TotalMonthManager_from_month, TotalMonthManager_from_manager_extracting_from_month
 from xulpymoney.libxulpymoneyfunctions import  qmessagebox
 from xulpymoney.casts import list2string, none2decimal0, lor_transposed
-from xulpymoney.ui.myqtablewidget import qcenter, qleft, mqtwObjects
+from xulpymoney.ui.myqtablewidget import qcenter, qleft, mqtwObjects, mqtw
 from xulpymoney.libxulpymoneytypes import eQColor, eMoneyCurrency
 from xulpymoney.objects.annualtarget import AnnualTarget
 from xulpymoney.objects.assets import Assets
 from xulpymoney.objects.accountoperation import AccountOperationManagerHeterogeneus
 from xulpymoney.objects.money import Money
-from xulpymoney.objects.percentage import Percentage
 from xulpymoney.ui.Ui_wdgTotal import Ui_wdgTotal
 
-class TotalMonth:
-    """All values are calculated in last day of the month"""
-    def __init__(self, mem, year, month):
-        self.mem=mem
-        self.year=year
-        self.month=month
-        self.expenses_value=None
-        self.no_loses_value=None
-        self.dividends_value=None
-        self.incomes_value=None
-        self.funds_revaluation_value=None
-        self.gains_value=None
-        self.total_accounts_value=None
-        self.total_investments_value=None
-        self.total_investments_high_low_value=None
-        self.total_zerorisk_value=None
-        self.total_bonds_value=None
-
-    def i_d_g_e(self):
-        return self.incomes()+self.dividends()+self.gains()+self.expenses()
-
-    def d_g(self):
-        """Dividends+gains"""
-        return self.gains()+self.dividends()
-
-    def expenses(self):
-        if self.expenses_value==None:
-            self.expenses_value=Assets(self.mem).saldo_por_tipo_operacion( self.year,self.month, 1)#La facturación de tarjeta dentro esta por el union
-        return self.expenses_value
-
-    def dividends(self):
-        if self.dividends_value==None:
-            self.dividends_value=Assets(self.mem).dividends_neto(  self.year, self.month)
-        return self.dividends_value
-
-    def incomes(self):
-        if self.incomes_value==None:
-            self.incomes_value=Assets(self.mem).saldo_por_tipo_operacion(  self.year,self.month,2)-self.dividends()
-        return self.incomes_value
-
-    def gains(self):
-        if self.gains_value==None:
-            self.gains_value=Assets(self.mem).consolidado_neto(self.mem.data.investments, self.year, self.month)
-        return self.gains_value
-
-    def funds_revaluation(self):
-        if self.funds_revaluation_value==None:
-            self.funds_revaluation_value=self.mem.data.investments_active().revaluation_monthly(2, self.year, self.month)#2 if type funds
-        return self.funds_revaluation_value
-
-    def name(self):
-        return "{}-{}".format(self.year, self.month)
-
-    def last_day(self):
-        return date_last_of_the_month(self.year, self.month)
-
-    def first_day(self):
-        return date(self.year, self.month, self.day)
-
-    def total(self):
-        """Total assests in the month"""
-        return self.total_accounts()+self.total_investments()
-
-    def total_accounts(self):
-        if self.total_accounts_value==None:
-            self.total_accounts_value=Assets(self.mem).saldo_todas_cuentas( self.last_day())
-        return self.total_accounts_value
-
-    def total_investments(self):
-        if self.total_investments_value==None:
-            self.total_investments_value=Assets(self.mem).saldo_todas_inversiones(self.last_day())
-        return self.total_investments_value
-
-    def total_investments_high_low(self):
-        if self.total_investments_high_low_value==None:
-            self.total_investments_high_low_value=Assets(self.mem).saldo_todas_inversiones_high_low(self.last_day())
-        return self.total_investments_high_low_value
-
-
-    def total_zerorisk(self): 
-        if self.total_zerorisk_value==None:
-            self.total_zerorisk_value=Assets(self.mem).patrimonio_riesgo_cero(self.last_day())
-        return self.total_zerorisk_value
-
-    def total_bonds(self):
-        if self.total_bonds_value==None:
-            self.total_bonds_value=Assets(self.mem).saldo_todas_inversiones_bonds(self.last_day())
-        return self.total_bonds_value
-
-    def total_no_losses(self):
-        if self.no_loses_value==None:
-            self.no_loses_value=Assets(self.mem).invested(self.last_day())+self.total_accounts()
-        return self.no_loses_value
-
-## Set of 12 totalmonths in the same year
-class TotalYear:
-    def __init__(self, mem, year):
-        self.mem=mem
-        self.year=year
-        self.arr=[]
-        self.total_last_year=Assets(self.mem).saldo_total(self.mem.data.investments,  date(self.year-1, 12, 31))
-        self.generate()
-
-    def generate(self):
-        for i in range(1, 13):
-            self.arr.append(TotalMonth(self.mem, self.year, i))
-
-    def find(self, year, month):
-        for m in self.arr:
-            if m.year==year and m.month==month:
-                return m
-        return None
-
-    def expenses(self):
-        result=Money(self.mem, 0, self.mem.localcurrency)
-        for m in self.arr:
-            result=result+m.expenses()
-        return result
-
-    def i_d_g_e(self):
-        return self.incomes()+self.dividends()+self.gains()+self.expenses()
-
-    def funds_revaluation(self):
-        return self.mem.data.investments_active().revaluation_annual(2, self.year)#2 if type funds
-
-    def incomes(self):
-        result=Money(self.mem, 0, self.mem.localcurrency)
-        for m in self.arr:
-            result=result+m.incomes()
-        return result
-
-    def gains(self):
-        result=Money(self.mem, 0, self.mem.localcurrency)
-        for m in self.arr:
-            result=result+m.gains()
-        return result        
-
-    def dividends(self):
-        result=Money(self.mem, 0, self.mem.localcurrency)
-        for m in self.arr:
-            result=result+m.dividends()
-        return result
-
-    def d_g(self):
-        """Dividends+gains"""
-        return self.gains()+self.dividends()
-
-    def difference_with_previous_month(self, totalmonth):
-        """Calculates difference between totalmonth and the total with previous month"""
-        if totalmonth.month==1:
-            totalprevious=self.total_last_year
-        else:
-            previous=self.find(self.year, totalmonth.month-1)
-            totalprevious=previous.total()
-        return totalmonth.total()-totalprevious
-
-    def difference_with_previous_year(self):
-        """Calculates difference between totalmonth of december and the total last year"""
-        return self.find(self.year, 12).total()-self.total_last_year
-
-    def assets_percentage_in_month(self, month):
-        """Calculates the percentage of the assets in this month from total last year"""
-        m=self.find(self.year, month)
-        return Percentage(m.total()-self.total_last_year, self.total_last_year)
-
-class TotalGraphic:
-    """Set of totalmonths to generate a graphic"""
-    def __init__(self, mem, startyear, startmonth):
-        self.mem=mem
-        self.startyear=startyear
-        self.startmonth=startmonth
-        self.arr=[]
-        self.generate()
-
-    def generate(self):
-        dt=date(self.startyear, self.startmonth, 1)-timedelta(days=1)#Previous month last day
-        while date.today()>=dt:
-            self.arr.append(TotalMonth(self.mem, dt.year, dt.month))
-            dt=date_first_of_the_next_x_months(dt.year, dt.month, 1)#Next month first day
-
-    def find(self, year, month):
-        for m in self.arr:
-            if m.year==year and m.month==month:
-                return m
-        return None
-
-    def length(self):
-        return len(self.arr)
 
 class wdgTotal(QWidget, Ui_wdgTotal):
     def __init__(self, mem,  parent=None):
@@ -216,8 +29,9 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         dtFirst=Assets(self.mem).first_datetime_allowed_estimated()  
         dtLast=Assets(self.mem).last_datetime_allowed_estimated()              
 
-        self.setData=None#Será un TotalYear
-        self.setGraphic=None #Será un TotalGraphic
+        #Adding more months that needed to allow month and december previous calculations
+        self.tmm=TotalMonthManager_from_month(self.mem, dtFirst.year, dtFirst.month, dtLast.year, 12)
+
         
         self.mqtw.setSettings(self.mem.settings, "wdgTotal", "mqtw")
         self.mqtw.table.cellDoubleClicked.connect(self.on_mqtw_cellDoubleClicked)
@@ -232,89 +46,86 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         self.annualtarget=None#AnnualTarget Object
         
         self.wyData.initiate(dtFirst.year,  dtLast.year, date.today().year)
-        self.wyChart.initiate(dtFirst.year,  dtLast.year, date.today().year-3)
+        self.wyChart.initiate(dtFirst.year,  date.today().year, date.today().year-3)
         self.wyChart.label.setText(self.tr("Data from selected year"))
 
         self.wdgTS.setSettings(self.mem.settings, "wdgTotal", "wdgTS")
+        self.wdgTSInvested.setSettings(self.mem.settings, "wdgTotal", "wdgTSInvested")
 
         self.tab.setCurrentIndex(0)
         self.tabData.setCurrentIndex(0)
         self.tabPlus.setCurrentIndex(0)
-        
-        self.pd= QProgressDialog("Loading data", None, 0,13    )
-        self.pd.setWindowIcon(QIcon(":/xulpymoney/coins.png"))
-        self.pd.setModal(True)
-        self.pd.setWindowTitle(QApplication.translate("Mem","Generating total report..."))
-        self.pd.forceShow()
-        self.progress_bar_update()
+
+
+        self.tmm_data=TotalMonthManager_from_manager_extracting_year(self.tmm, self.wyData.year)        
+        self.tmm_graphics=TotalMonthManager_from_manager_extracting_from_month(self.tmm, self.wyChart.year, 1, date.today().year, date.today().month)
 
         self.load_data()
         self.load_targets()
         self.load_targets_with_funds_revaluation()
         self.load_invest_or_work()
         self.load_make_ends_meet()
-        self.progress_bar_update()
         self.wyData.changed.connect(self.on_wyData_mychanged)#Used my due to it took default on_wyData_changed
         self.wyChart.changed.connect(self.on_wyChart_mychanged)
 
-    ## One step forward
-    def progress_bar_update(self):
-        self.pd.setValue(self.pd.value()+1)
-        self.pd.update()
-        QApplication.processEvents()
-
-        
 
     def load_data(self):
         inicio=datetime.now()
-        self.setData=TotalYear(self.mem, self.wyData.year)
+                
+        pd= QProgressDialog("Loading data", None, 0, 12)
+        pd.setWindowIcon(QIcon(":/xulpymoney/coins.png"))
+        pd.setModal(True)
+        pd.setWindowTitle(QApplication.translate("Mem","Generating total report..."))
+        pd.forceShow()
+        pd.setValue(0)
+        
         
         hh=[self.tr("January"),  self.tr("February"), self.tr("March"), self.tr("April"), self.tr("May"), self.tr("June"), self.tr("July"), self.tr("August"), self.tr("September"), self.tr("October"), self.tr("November"), self.tr("December"), self.tr("Total")]
         hv=[self.tr("Incomes"), self.tr("Gains"), self.tr("Dividends"), self.tr("Expenses"), self.tr("I+G+D+E"), "", self.tr("Accounts"), self.tr("Investments"), self.tr("Total"), self.tr("Monthly difference"), "", self.tr("% Year to date")]
         data=[]
-        for i, m in enumerate(self.setData.arr):
-            if m.year<date.today().year or (m.year==date.today().year and m.month<=date.today().month):
-                row=[]
-                row.append(m.incomes())
-                row.append(m.gains())
-                row.append(m.dividends())
-                row.append(m.expenses())
-                row.append(m.i_d_g_e())
-                row.append("")
-                row.append(m.total_accounts())
-                row.append(m.total_investments())
-                row.append(m.total())
-                row.append(self.setData.difference_with_previous_month(m))
-                row.append("")
-                row.append(self.setData.assets_percentage_in_month(m.month))        
-            else:
-                row=[""]*12
-            data.append(row)
-            self.progress_bar_update()
-        row=[]
-        row.append(self.setData.incomes())
-        row.append(self.setData.gains())
-        row.append(self.setData.dividends())
-        row.append(self.setData.expenses())
-        row.append(self.setData.i_d_g_e())
-        row.append("")
-        row.append("")
-        row.append("")
-        row.append("")
-        row.append(self.setData.difference_with_previous_year())
-        row.append("")
-        row.append(self.setData.assets_percentage_in_month(12))        
-        data.append(row)
+        tm_previous_december=self.tmm.find_previous_december(self.tmm_data.first())
+        for m in self.tmm_data:
+            tm_previous=self.tmm.find_previous(m)
+            data.append([
+                m.incomes(),
+                m.gains(),
+                m.dividends(),
+                m.expenses(),
+                m.i_d_g_e(),
+                "", 
+                m.total_accounts(),
+                m.total_investments_real(),
+                m.total_real(),
+                m.total_difference(tm_previous),
+                "", 
+                m.total_difference_percentage(tm_previous_december),
+            ])
+            pd.setValue(pd.value()+1)
+            QApplication.processEvents()
+        data.append([
+            self.tmm_data.incomes(),
+            self.tmm_data.gains(),
+            self.tmm_data.dividends(),
+            self.tmm_data.expenses(),
+            self.tmm_data.i_d_g_e(),
+            "", 
+            "", 
+            "", 
+            "", 
+            self.tmm_data.last().total_difference(tm_previous_december),
+            "", 
+            self.tmm_data.last().total_difference_percentage(tm_previous_december),
+        ])
         data=lor_transposed(data)
         self.mqtw.setData(hh, hv, data)
         
         self.mqtw.table.setCurrentCell(6, date.today().month-1)
-        self.lblPreviousYear.setText(self.tr("Balance at {0}-12-31: {1}".format(self.setData.year-1, self.setData.total_last_year)))
-
+        tm_lastyear=self.tmm.find(self.wyData.year-1, 12)
+        self.lblPreviousYear.setText(self.tr("Balance at {0}-12-31: {1}".format(tm_lastyear.year, tm_lastyear.total())))
 
         invested=Assets(self.mem).invested(date.today())
         current=Assets(self.mem).saldo_todas_inversiones( date.today())
-        s=self.tr("This year I've generated {}.").format(self.setData.gains()+self.setData.dividends())
+        s=self.tr("This year I've generated {}.").format(self.tmm_data.gains()+self.tmm_data.dividends())
         s=s+"\n"+self.tr("Difference between invested amount and current invesment balance: {} - {} = {}").format(invested,  current,  current-invested)
         self.lblInvested.setText(s)
 
@@ -335,8 +146,8 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         self.mqtwTargets.applySettings()
         inicio=datetime.now()     
         sumd_g=Money(self.mem, 0, self.mem.localcurrency)
-        for i in range(1, 13): 
-            m=self.setData.find(self.setData.year, i)
+        for i, m in enumerate(self.tmm_data): 
+            i=i+1
             sumd_g=sumd_g+m.d_g()
             self.mqtwTargets.table.setItem(0, i-1, self.mem.localmoney(self.annualtarget.monthly_balance()).qtablewidgetitem())
             self.mqtwTargets.table.setItem(1, i-1, self.mem.localmoney(m.d_g().amount).qtablewidgetitem_with_target(self.annualtarget.monthly_balance()))
@@ -369,8 +180,8 @@ class wdgTotal(QWidget, Ui_wdgTotal):
 
         sumd_g=Money(self.mem, 0, self.mem.localcurrency)
         sumf=Money(self.mem, 0, self.mem.localcurrency)
-        for i in range(1, 13): 
-            m=self.setData.find(self.setData.year, i)
+        for i, m in enumerate(self.tmm_data): 
+            i=i+1
             sumd_g=sumd_g+m.d_g()
             sumf=sumf+m.funds_revaluation()
             self.mqtwTargetsPlus.table.setItem(0, i-1, self.mem.localmoney(self.annualtarget.monthly_balance()).qtablewidgetitem())
@@ -422,16 +233,16 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         self.mqtwInvestOrWork.table.verticalHeader().show()       
         self.mqtwInvestOrWork.table.clearContents()
         self.mqtwInvestOrWork.applySettings()
-        for i in range(1, 13): 
-            m=self.setData.find(self.setData.year, i)
+        for i, m in enumerate(self.tmm_data): 
+            i=i+1
             self.mqtwInvestOrWork.table.setItem(0, i-1, m.d_g().qtablewidgetitem())
             self.mqtwInvestOrWork.table.setItem(1, i-1, m.expenses().qtablewidgetitem())
             self.mqtwInvestOrWork.table.setItem(3, i-1, (m.d_g()+m.expenses()).qtablewidgetitem())#Es mas porque es - y gastos -
             self.mqtwInvestOrWork.table.setItem(5, i-1, qresult(m.d_g()+m.expenses()))
-        self.mqtwInvestOrWork.table.setItem(0, 12, self.setData.d_g().qtablewidgetitem())
-        self.mqtwInvestOrWork.table.setItem(1, 12, self.setData.expenses().qtablewidgetitem())
-        self.mqtwInvestOrWork.table.setItem(3, 12, (self.setData.d_g()+self.setData.expenses()).qtablewidgetitem())
-        self.mqtwInvestOrWork.table.setItem(5, 12, qresult(self.setData.d_g()+self.setData.expenses()))
+        self.mqtwInvestOrWork.table.setItem(0, 12, self.tmm_data.d_g().qtablewidgetitem())
+        self.mqtwInvestOrWork.table.setItem(1, 12, self.tmm_data.expenses().qtablewidgetitem())
+        self.mqtwInvestOrWork.table.setItem(3, 12, (self.tmm_data.d_g()+self.tmm_data.expenses()).qtablewidgetitem())
+        self.mqtwInvestOrWork.table.setItem(5, 12, qresult(self.tmm_data.d_g()+self.tmm_data.expenses()))
         self.mqtwInvestOrWork.table.setCurrentCell(2, date.today().month-1)   
         
         s=""
@@ -467,16 +278,16 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         self.mqtwMakeEndsMeet.table.verticalHeader().show()      
         self.mqtwMakeEndsMeet.table.clearContents()
         self.mqtwMakeEndsMeet.applySettings()
-        for i in range(1, 13): 
-            m=self.setData.find(self.setData.year, i)
+        for i, m in enumerate(self.tmm_data): 
+            i=i+1
             self.mqtwMakeEndsMeet.table.setItem(0, i-1, m.incomes().qtablewidgetitem())
             self.mqtwMakeEndsMeet.table.setItem(1, i-1, m.expenses().qtablewidgetitem())
             self.mqtwMakeEndsMeet.table.setItem(3, i-1, (m.incomes()+m.expenses()).qtablewidgetitem())#Es mas porque es - y gastos -
             self.mqtwMakeEndsMeet.table.setItem(5, i-1, qresult(m.incomes()+m.expenses()))
-        self.mqtwMakeEndsMeet.table.setItem(0, 12, self.setData.incomes().qtablewidgetitem())
-        self.mqtwMakeEndsMeet.table.setItem(1, 12, self.setData.expenses().qtablewidgetitem())
-        self.mqtwMakeEndsMeet.table.setItem(3, 12, (self.setData.incomes()+self.setData.expenses()).qtablewidgetitem())
-        self.mqtwMakeEndsMeet.table.setItem(5, 12, qresult(self.setData.incomes()+self.setData.expenses()))
+        self.mqtwMakeEndsMeet.table.setItem(0, 12, self.tmm_data.incomes().qtablewidgetitem())
+        self.mqtwMakeEndsMeet.table.setItem(1, 12, self.tmm_data.expenses().qtablewidgetitem())
+        self.mqtwMakeEndsMeet.table.setItem(3, 12, (self.tmm_data.incomes()+self.tmm_data.expenses()).qtablewidgetitem())
+        self.mqtwMakeEndsMeet.table.setItem(5, 12, qresult(self.tmm_data.incomes()+self.tmm_data.expenses()))
         self.mqtwMakeEndsMeet.table.setCurrentCell(2, date.today().month-1)   
         
         s=""
@@ -488,25 +299,24 @@ class wdgTotal(QWidget, Ui_wdgTotal):
 
     def load_graphic(self, animations=True):               
         inicio=datetime.now()  
-        
-        self.setGraphic=TotalGraphic(self.mem, self.wyChart.year, 1)
 
         self.wdgTS.clear()
         self.wdgTS.ts.setAnimations(animations)
         
         #Series creation
-        last=self.setGraphic.find(date.today().year, date.today().month)
+        last=self.tmm_graphics.last()
         lsNoLoses=self.wdgTS.ts.appendTemporalSeries(self.tr("Total without losses assets")+": {}".format(last.total_no_losses()))
         lsMain=self.wdgTS.ts.appendTemporalSeries(self.tr("Total assets")+": {}".format(last.total()))
         lsZero=self.wdgTS.ts.appendTemporalSeries(self.tr("Zero risk assets")+": {}".format(last.total_zerorisk()))
         lsBonds=self.wdgTS.ts.appendTemporalSeries(self.tr("Bond assets")+": {}".format(last.total_bonds()))
         lsRisk=self.wdgTS.ts.appendTemporalSeries(self.tr("Risk assets")+": {}".format(last.total()-last.total_zerorisk()-last.total_bonds()))
 
-        progress = QProgressDialog(self.tr("Filling report data"), self.tr("Cancel"), 0,self.setGraphic.length())
+        progress = QProgressDialog(self.tr("Filling report data"), self.tr("Cancel"), 0,self.tmm_graphics.length())
         progress.setModal(True)
         progress.setWindowTitle(self.tr("Calculating data..."))
         progress.setWindowIcon(QIcon(":/xulpymoney/coins.png"))
-        for m in self.setGraphic.arr:
+        progress.setValue(0)
+        for m in self.tmm_graphics:
             if progress.wasCanceled():
                 break
             progress.setValue(progress.value()+1)
@@ -514,16 +324,50 @@ class wdgTotal(QWidget, Ui_wdgTotal):
             total=m.total().amount
             zero=m.total_zerorisk().amount
             bonds=m.total_bonds().amount
-            self.wdgTS.ts.appendTemporalSeriesData(lsMain, epoch, m.total().amount)
+            self.wdgTS.ts.appendTemporalSeriesData(lsMain, epoch, m.total_real().amount)
             self.wdgTS.ts.appendTemporalSeriesData(lsZero, epoch, m.total_zerorisk().amount)
             self.wdgTS.ts.appendTemporalSeriesData(lsBonds, epoch, m.total_bonds().amount)
             self.wdgTS.ts.appendTemporalSeriesData(lsRisk, epoch, total-zero-bonds)
-            self.wdgTS.ts.appendTemporalSeriesData(lsNoLoses, epoch, m.total_no_losses().amount)
+            self.wdgTS.ts.appendTemporalSeriesData(lsNoLoses, epoch, m.total_no_losses_real().amount)
         self.wdgTS.display()
         
         info("wdgTotal > load_graphic: {0}".format(datetime.now()-inicio))
+        self.load_graphic_invested(animations)
+        
+        
+    def load_graphic_invested(self, animations=True):               
+        inicio=datetime.now()  
+
+        self.wdgTSInvested.clear()
+        self.wdgTSInvested.ts.setAnimations(animations)
+        
+        #Series creation
+        last=self.tmm_graphics.last()
+        lsNoLoses=self.wdgTSInvested.ts.appendTemporalSeries(self.tr("Total without losses assets")+": {}".format(last.total_no_losses()))
+        lsMain=self.wdgTSInvested.ts.appendTemporalSeries(self.tr("Total assets")+": {}".format(last.total()))
+        lsInvested=self.wdgTSInvested.ts.appendTemporalSeries(self.tr("Invested assets") + ": {}".format(last.total_invested()))
+        lsAccounts=self.wdgTSInvested.ts.appendTemporalSeries(self.tr("Accounts assets") + ": {}".format(last.total_accounts()))
+
+        progress = QProgressDialog(self.tr("Filling report data"), self.tr("Cancel"), 0,self.tmm_graphics.length())
+        progress.setModal(True)
+        progress.setWindowTitle(self.tr("Calculating data..."))
+        progress.setWindowIcon(QIcon(":/xulpymoney/coins.png"))
+        progress.setValue(0)
+        for m in self.tmm_graphics:
+            if progress.wasCanceled():
+                break
+            progress.setValue(progress.value()+1)
+            epoch=dtaware_day_end_from_date(m.last_day(), self.mem.localzone_name)
+            self.wdgTSInvested.ts.appendTemporalSeriesData(lsMain, epoch, m.total_real().amount)
+            self.wdgTSInvested.ts.appendTemporalSeriesData(lsNoLoses, epoch, m.total_no_losses_real().amount)
+            self.wdgTSInvested.ts.appendTemporalSeriesData(lsInvested, epoch, m.total_invested_real().amount)
+            self.wdgTSInvested.ts.appendTemporalSeriesData(lsAccounts, epoch, m.total_accounts().amount)
+        self.wdgTSInvested.display()
+        
+        info("wdgTotal > load_graphic_invested: {0}".format(datetime.now()-inicio))
 
     def on_wyData_mychanged(self):
+        self.tmm_data=TotalMonthManager_from_manager_extracting_year(self.tmm, self.wyData.year)
         self.load_data()    
         self.load_targets()
         self.load_targets_with_funds_revaluation()
@@ -531,6 +375,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         self.load_make_ends_meet()
 
     def on_wyChart_mychanged(self):
+        self.tmm_graphics=TotalMonthManager_from_manager_extracting_from_month(self.tmm, self.wyChart.year, 1, date.today().year, date.today().month)
         self.load_graphic()      
         
     def on_cmdTargets_released(self):
@@ -554,6 +399,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         
         id_tiposoperaciones=2
         set=AccountOperationManagerHeterogeneus(self.mem)
+        conceptslist=ConceptManager_considered_dividends_in_totals(self.mem).array_of_ids()
         if self.month==13:#Year
             tabtitle=self.tr("Incomes of {}").format(self.wyData.year)
             set.load_from_db("""select id_opercuentas, datetime, id_conceptos, id_tiposoperaciones, importe, comentario, id_cuentas 
@@ -565,7 +411,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
                                                     from opertarjetas,tarjetas 
                                                     where opertarjetas.id_tarjetas=tarjetas.id_tarjetas and 
                                                         id_tiposoperaciones={0} and 
-                                                        date_part('year',datetime)={1}""".format (id_tiposoperaciones, self.wyData.year, list2string(self.mem.conceptos.considered_dividends_in_totals())))
+                                                        date_part('year',datetime)={1}""".format (id_tiposoperaciones, self.wyData.year, list2string(conceptslist)))
         else:#Month
             tabtitle=self.tr("Incomes of {0} of {1}").format(self.mqtw.table.horizontalHeaderItem(self.month-1).text(), self.wyData.year)
             set.load_from_db("""select id_opercuentas, datetime, id_conceptos, id_tiposoperaciones, importe, comentario, id_cuentas 
@@ -579,7 +425,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
                                                     where opertarjetas.id_tarjetas=tarjetas.id_tarjetas and 
                                                         id_tiposoperaciones={0} and 
                                                         date_part('year',datetime)={1} and 
-                                                        date_part('month',datetime)={2}""".format (id_tiposoperaciones, self.wyData.year, self.month, list2string(self.mem.conceptos.considered_dividends_in_totals())))
+                                                        date_part('month',datetime)={2}""".format (id_tiposoperaciones, self.wyData.year, self.month, list2string(conceptslist)))
         set.myqtablewidget(wdg,  True)
         wdg.drawOrderBy(0, False)
         horizontalLayout.addWidget(wdg)
@@ -648,7 +494,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
                 for o in i.op_historica.arr:
                     if self.month==13:#Year
                         tabtitle=self.tr("Selling operations of {0}").format(self.wyData.year)
-                        if o.fecha_venta.year==self.wyData.year:
+                        if o.dt_end.year==self.wyData.year:
                             set.arr.append(o)
                             if o.consolidado_bruto().isGETZero():
                                 positive=positive+o.consolidado_bruto().local()
@@ -656,7 +502,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
                                 negative=negative+o.consolidado_bruto().local()
                     else:#Month
                         tabtitle=self.tr("Selling operations of {0} of {1}").format(self.mqtw.table.horizontalHeaderItem(self.month-1).text(), self.wyData.year)
-                        if o.fecha_venta.year==self.wyData.year and o.fecha_venta.month==self.month:#Venta y traspaso fondos inversion
+                        if o.dt_end.year==self.wyData.year and o.dt_end.month==self.month:#Venta y traspaso fondos inversion
                             set.arr.append(o)
                             if o.consolidado_bruto().isGETZero():
                                 positive=positive+o.consolidado_bruto().local()
@@ -685,7 +531,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
                 for o in i.op_historica.arr:
                     if self.month==13:#Year
                         tabtitle=self.tr("Selling operations of {0}  (Sold after a year)").format(self.wyData.year)
-                        if o.fecha_venta.year==self.wyData.year and o.tipooperacion.id in (5, 8)  and o.less_than_a_year()==False:#Venta y traspaso fondos inversion
+                        if o.dt_end.year==self.wyData.year and o.tipooperacion.id in (5, 8)  and o.less_than_a_year()==False:#Venta y traspaso fondos inversion
                             set.arr.append(o)
                             if o.consolidado_bruto()>=0:
                                 positive=positive+o.consolidado_bruto()
@@ -693,7 +539,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
                                 negative=negative+o.consolidado_bruto()
                     else:#Month
                         tabtitle=self.tr("Selling operations of {0} of {1} (Sold after a year)").format(self.mqtw.table.horizontalHeaderItem(self.month-1).text(), self.wyData.year)
-                        if o.fecha_venta.year==self.wyData.year and o.fecha_venta.month==self.month and o.tipooperacion.id in (5, 8)  and o.less_than_a_year()==False:#Venta y traspaso fondos inversion
+                        if o.dt_end.year==self.wyData.year and o.dt_end.month==self.month and o.tipooperacion.id in (5, 8)  and o.less_than_a_year()==False:#Venta y traspaso fondos inversion
                             set.arr.append(o)
                             if o.consolidado_bruto()>=0:
                                 positive=positive+o.consolidado_bruto()
@@ -722,7 +568,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
                 for o in i.op_historica.arr:
                     if self.month==13:#Year
                         tabtitle=self.tr("Selling operations of {0} (Sold before a year)").format(self.wyData.year)
-                        if o.fecha_venta.year==self.wyData.year and o.tipooperacion.id in (5, 8) and o.less_than_a_year()==True:#Venta y traspaso fondos inversion
+                        if o.dt_end.year==self.wyData.year and o.tipooperacion.id in (5, 8) and o.less_than_a_year()==True:#Venta y traspaso fondos inversion
                             set.arr.append(o)
                             if o.consolidado_bruto()>=0:
                                 positive=positive+o.consolidado_bruto()
@@ -730,7 +576,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
                                 negative=negative+o.consolidado_bruto()
                     else:#Month
                         tabtitle=self.tr("Selling operations of {0} of {1} (Sold before a year)").format(self.mqtw.table.horizontalHeaderItem(self.month-1).text(), self.wyData.year)
-                        if o.fecha_venta.year==self.wyData.year and o.fecha_venta.month==self.month and o.tipooperacion.id in (5, 8) and o.less_than_a_year()==True:#Venta y traspaso fondos inversion
+                        if o.dt_end.year==self.wyData.year and o.dt_end.month==self.month and o.tipooperacion.id in (5, 8) and o.less_than_a_year()==True:#Venta y traspaso fondos inversion
                             set.arr.append(o)
                             if o.consolidado_bruto()>=0:
                                 positive=positive+o.consolidado_bruto()
@@ -867,16 +713,11 @@ class wdgTotal(QWidget, Ui_wdgTotal):
     def on_actionGainsByProductType_triggered(self):
         newtab = QWidget()
         vlayout = QVBoxLayout(newtab)
-        wdg = mqtwObjects(newtab)
+        wdg = mqtw(newtab)
         wdg.setSettings(self.mem.settings,"wdgTotal","mqtwGainsByProductType")
-        wdg.table.setEditTriggers(QAbstractItemView.NoEditTriggers)
-        wdg.table.setColumnCount(5)
+        headers=[self.tr( "Product type" ), self.tr( "Gross gains" ), self.tr("Gross dividends"), self.tr( "Net gains" ), self.tr("Net dividends")]
+        
         
-        wdg.table.setHorizontalHeaderItem(0, QTableWidgetItem(self.tr( "Product type" )))
-        wdg.table.setHorizontalHeaderItem(1, QTableWidgetItem(self.tr( "Gross gains" )))
-        wdg.table.setHorizontalHeaderItem(2, QTableWidgetItem(self.tr("Gross dividends")))
-        wdg.table.setHorizontalHeaderItem(3, QTableWidgetItem(self.tr( "Net gains" )))
-        wdg.table.setHorizontalHeaderItem(4, QTableWidgetItem(self.tr("Net dividends")))
         wdg.applySettings()
         sum_gains=Money(self.mem)
         sum_dividens=Money(self.mem)
@@ -886,17 +727,18 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         settypes=self.mem.types.investment_types()
         wdg.table.setRowCount(settypes.length()+1)
         
+        data=[]
         for i, type in enumerate(settypes.arr):
             wdg.table.setItem(i, 0, qleft(type.name))    
             gains=Money(self.mem,  0,  self.mem.localcurrency)
             netgains=Money(self.mem, 0, self.mem.localcurrency)
             dividends=Money(self.mem,  0,  self.mem.localcurrency)
-            netdividens=Money(self.mem,  0, self.mem.localcurrency)
+            netdividends=Money(self.mem,  0, self.mem.localcurrency)
             for inv in self.mem.data.investments.arr:
                 if inv.product.type.id==type.id:
                     #gains
                     for o in inv.op_historica.arr:
-                        if o.fecha_venta.year==self.wyData.year:
+                        if o.dt_end.year==self.wyData.year:
                             gains=gains+o.consolidado_bruto(eMoneyCurrency.User)
                             netgains=netgains+o.consolidado_neto(eMoneyCurrency.User)
                     #dividends
@@ -904,22 +746,15 @@ class wdgTotal(QWidget, Ui_wdgTotal):
                     for d in inv.dividends.arr:
                         if d.datetime.year==self.wyData.year:
                             dividends=dividends+d.gross(eMoneyCurrency.User)
-                            netdividens=netdividens+d.net(eMoneyCurrency.User)
-            wdg.table.setItem(i, 1, gains.qtablewidgetitem())
-            wdg.table.setItem(i, 2, dividends.qtablewidgetitem())
-            wdg.table.setItem(i, 3, netgains.qtablewidgetitem())
-            wdg.table.setItem(i, 4, netdividens.qtablewidgetitem())
+                            netdividends=netdividends+d.net(eMoneyCurrency.User)
+            data.append([type.name, gains, dividends, netgains, netdividends])
             sum_gains=sum_gains+gains
             sum_netgains=sum_netgains+netgains
             sum_dividens=sum_dividens+dividends
-            sum_netdividends=sum_netdividends+netdividens
-            
-        wdg.table.setItem(i+1, 0, qleft(self.tr("Total")))
-        wdg.table.setItem(i+1, 1, sum_gains.qtablewidgetitem())
-        wdg.table.setItem(i+1, 2, sum_dividens.qtablewidgetitem())
-        wdg.table.setItem(i+1, 3, sum_netgains.qtablewidgetitem())
-        wdg.table.setItem(i+1, 4, sum_netdividends.qtablewidgetitem())
-        
+            sum_netdividends=sum_netdividends+netdividends
+        data.append([self.tr("Total"), sum_gains, sum_dividens, sum_netgains, sum_netdividends])
+        wdg.setData(headers, None, data)
+
         label=QLabel(newtab)
         font = QFont()
         font.setPointSize(8)
@@ -933,7 +768,7 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         vlayout.addWidget(label)
         self.tab.addTab(newtab, self.tr("Gains by product type of {}").format(self.wyData.year))
         self.tab.setCurrentWidget(newtab)        
-            
+
     @pyqtSlot() 
     def on_actionShowTaxes_triggered(self):
         newtab = QWidget()
@@ -1030,8 +865,8 @@ class wdgTotal(QWidget, Ui_wdgTotal):
         elif row==3: #Expenses
             self.on_actionShowExpenses_triggered()
         elif row==7: #Investments
-            totalmonth=self.setData.arr[column]
-            qmessagebox(self.tr("High Low Investments aren't sumarized here, due to they have daily adjustments in accounts.") + "\n\n" + self.tr("Their balance at the end of {}-{} is {}").format(totalmonth.year, totalmonth.month, totalmonth.total_investments_high_low()))
+            totalmonth=self.tmm_data.arr[column]
+            qmessagebox(self.tr("Investments with daily adjustments aren't sumarized here, due to they are sumarized in accounts.") + "\n\n" + self.tr("Their balance at the end of {}-{} is {}").format(totalmonth.year, totalmonth.month, totalmonth.total_investments_with_daily_adjustments()))
         else:
             qmessagebox(self.tr("You only can double click in incomes, gains, dividends and expenses.") + "\n\n" + self.tr("Make right click to see commission and tax reports"))
 
